@@ -60,6 +60,7 @@ class fillVars(object, cl_base.glob_attr):
         if linuxShortName:
             dictLinuxName = {"CLD":"Calculate Linux Desktop",
                              "CLDX":"Calculate Linux Desktop",
+                             "CLDG":"Calculate Linux Desktop",
                              "CDS":"Calculate Directory Server",
                              "Gentoo":"Gentoo"}
             if linuxShortName in dictLinuxName.keys():
@@ -73,7 +74,7 @@ class fillVars(object, cl_base.glob_attr):
         """постфикс к названию системы"""
         linuxShortName = self.Get("os_linux_shortname")
         if linuxShortName:
-            dictLinuxSubName = {"CLD":"KDE", "CLDX":"XFCE"}
+            dictLinuxSubName = {"CLD":"KDE", "CLDX":"XFCE", "CLDG":"GNOME"}
             if linuxShortName in dictLinuxSubName.keys():
                 return dictLinuxSubName[linuxShortName]
             else:
